Batch

Struct Batch 

pub struct Batch<T, Request>
where T: Service<BatchControl<Request>>,
{ /* private fields */ }
Allows batch processing of requests.

See the module documentation for more details.

Implementations

Source

impl<T, Request> Batch<T, Request>
where T: Service<BatchControl<Request>>, T::Error: Into<BoxError>,

pub fn new(service: T, size: usize, time: Duration) -> Self
where T: Send + 'static, T::Future: Send, T::Error: Send + Sync, Request: Send + 'static,

Creates a new Batch wrapping service.

The wrapper is responsible for telling the inner service when to flush a batch of requests.

The default Tokio executor is used to run the given service, which means that this method must be called while on the Tokio runtime.

pub fn pair( service: T, size: usize, time: Duration, ) -> (Self, Worker<T, Request>)
where T: Send + 'static, T::Future: Send, T::Error: Send + Sync, Request: Send + 'static,

Creates a new Batch wrapping service, but returns the background worker.

This is useful if you do not want to spawn directly onto the tokio runtime but instead want to use your own executor. This will return the Batch and the background Worker that you can then spawn.