pub struct BatchLayer<Request> { /* private fields */ }Expand description
A Layer that wraps an inner service with Batch.
The background worker is spawned on the default Tokio executor, so this layer can only be used on the Tokio runtime.
See the module documentation for the full lifecycle and error semantics.
Implementations
Sourceimpl<Request> BatchLayer<Request>
impl<Request> BatchLayer<Request>
Sourcepub fn new(size: usize, time: Duration) -> Self
pub fn new(size: usize, time: Duration) -> Self
Creates a new BatchLayer.
size– the maximum number of items per batch.time– the maximum duration before a batch is flushed.